# ---------------------------
# VPCモジュールの実行
# ---------------------------
module "vpc" {
  source      = "../../modules/vpc"
  name_prefix = var.name_prefix
  env         = var.env

  vpc_cidr_block  = var.vpc_cidr_block
  vpc_name        = var.vpc_name
  public_1a_cidr  = var.public_1a_cidr
  public_1c_cidr  = var.public_1c_cidr
  private_1a_cidr = var.private_1a_cidr
  private_1c_cidr = var.private_1c_cidr
  public_1a_name  = var.public_1a_name
  public_1c_name  = var.public_1c_name
  private_1a_name = var.private_1a_name
  private_1c_name = var.private_1c_name
  igw_name        = var.igw_name
  public_rtb_name = var.public_rtb_name
}

# ---------------------------
# SecurityGroupモジュールの実行
# ---------------------------
module "securitygroup" {
  source      = "../../modules/securitygroup"
  name_prefix = var.name_prefix
  env         = var.env

  vpc_id         = module.vpc.vpc_id
  vpc_cidr_block = module.vpc.vpc_cidr_block
  ec2_sg_name    = var.ec2_sg_name
  rds_sg_name    = var.rds_sg_name
  alb_sg_name    = var.alb_sg_name
}

# ---------------------------
# EC2モジュールの実行
# ---------------------------
module "ec2" {
  source      = "../../modules/ec2"
  name_prefix = var.name_prefix
  env         = var.env

  aws_subnet_public_1a_id = module.vpc.aws_subnet_public_1a_id
  aws_subnet_public_1c_id = module.vpc.aws_subnet_public_1c_id
  ec2_sg_id               = module.securitygroup.ec2_sg_id
  rds_sg_id               = module.securitygroup.rds_sg_id

  key_name        = var.key_name
  web1_private_ip = var.web1_private_ip
  web2_private_ip = var.web2_private_ip
  ni_web1_name    = var.ni_web1_name
  ni_web2_name    = var.ni_web2_name
  ec2_web1_name   = var.ec2_web1_name
  ec2_web2_name   = var.ec2_web2_name

}

# ---------------------------
# RDSモジュールの実行
# ---------------------------
module "rds" {
  source      = "../../modules/rds"
  name_prefix = var.name_prefix
  env         = var.env

  aws_subnet_private_1a_id = module.vpc.aws_subnet_private_1a_id
  aws_subnet_private_1c_id = module.vpc.aws_subnet_private_1c_id
  rds_sg_id                = module.securitygroup.rds_sg_id

  db_subnet_group_name = var.db_subnet_group_name
  rds_identifier       = var.rds_identifier
  rds_db_name          = var.rds_db_name
  rds_username         = var.rds_username
  rds_password         = var.rds_password
}

# ---------------------------
# ALBモジュールの実行
# ---------------------------
module "alb" {
  source      = "../../modules/alb"
  name_prefix = var.name_prefix
  env         = var.env

  alb_sg_id               = module.securitygroup.alb_sg_id
  aws_subnet_public_1a_id = module.vpc.aws_subnet_public_1a_id
  aws_subnet_public_1c_id = module.vpc.aws_subnet_public_1c_id
  vpc_id                  = module.vpc.vpc_id
  ec2_web1_id             = module.ec2.ec2_web1_id
  ec2_web2_id             = module.ec2.ec2_web2_id

  alb_name          = var.alb_name
  target_group_name = var.target_group_name

}
